@@ -1,14 +1,14 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 use warnings;
 
 package Mail::Box::Maildir::Message;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.090';
 
 use base 'Mail::Box::Dir::Message';
 
@@ -24,7 +24,7 @@ sub filename(;$)
     return $newname if defined $oldname && $oldname eq $newname;
 
     my ($id, $semantics, $flags)
-     = $newname =~ m!(.*?)(?:\:([12])\,([A-Z]*))!
+     = $newname =~ m!(.*?)(?:\:([12])\,([A-Za-z]*))!
      ? ($1, $2, $3)
      : ($newname, '','');
 
@@ -32,13 +32,14 @@ sub filename(;$)
     $flags{$_}++ foreach split //, $flags;
 
     $self->SUPER::label
-     ( draft   => ($flags{D} || 0)
-     , flagged => ($flags{F} || 0)
-     , replied => ($flags{R} || 0)
-     , seen    => ($flags{S} || 0)
-     , deleted => ($flags{T} || 0)
+     ( draft   => (delete $flags{D} || 0)
+     , flagged => (delete $flags{F} || 0)
+     , replied => (delete $flags{R} || 0)
+     , seen    => (delete $flags{S} || 0)
+     , deleted => (delete $flags{T} || 0)
 
-     , passed  => ($flags{P} || 0)   # uncommon
+     , passed  => (delete $flags{P} || 0)    # uncommon
+     , unknown => join('', sort keys %flags) # application specific
      );
 
     if(defined $oldname && ! move $oldname, $newname)
@@ -89,7 +90,8 @@ sub labelsToFilename()
       . ($labels->{passed}  ? 'P' : '')
       . ($labels->{replied} ? 'R' : '')
       . ($labels->{seen}    ? 'S' : '')
-      . ($labels->{deleted} ? 'T' : '');
+      . ($labels->{deleted} ? 'T' : '')
+      . ($labels->{unknown} || '');
 
     my $newset = $labels->{accepted} ? 'cur' : 'new';
     if($set ne $newset)
