@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Box::Manager;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.090';
 
 use base 'Mail::Reporter';
 
@@ -439,16 +439,23 @@ sub copyMessage(@)
     $folder = $self->isOpenFolder($folder) || $folder
         unless ref $folder;
 
-    my @coerced
-     = ref $folder
-     ? map {$_->copyTo($folder, share => $args{share})} @messages
-     : $self->appendMessages(@messages, %args, folder => $folder);
-
-    # hidden option, do not use it: it's designed to optimize moveMessage
-    if($args{_delete})
-    {   $_->label(deleted => 1) foreach @messages;
+    unless(ref $folder)
+    {   my @c = $self->appendMessages(@messages, %args, folder => $folder);
+        if($args{_delete})
+        {   $_->label(deleted => 1) for @messages;
+        }
+        return @c;
     }
 
+    my @coerced;
+    foreach my $msg (@messages)
+    {   if($msg->folder eq $folder)  # ignore move to same folder
+        {   push @coerced, $msg;
+            next;
+        }
+        push @coerced, $msg->copyTo($folder, share => $args{share});
+        $msg->label(deleted => 1) if $args{_delete};
+    }
     @coerced;
 }
 
@@ -463,9 +470,6 @@ sub moveMessage(@)
 #-------------------------------------------
 
 
-#-------------------------------------------
-
-
 sub threads(@)
 {   my $self    = shift;
     my @folders;
@@ -518,16 +522,12 @@ sub toBeThreaded($@)
     $_->toBeThreaded(@_) foreach @{$self->{MBM_threads}};
 }
 
-#-------------------------------------------
-
 
 sub toBeUnthreaded($@)
 {   my $self = shift;
     $_->toBeUnthreaded(@_) foreach @{$self->{MBM_threads}};
 }
 
-#-------------------------------------------
-
 
 sub decodeFolderURL($)
 {   my ($self, $name) = @_;
@@ -546,10 +546,12 @@ sub decodeFolderURL($)
                       !x;
 
     $username ||= $ENV{USER} || $ENV{LOGNAME};
+    $password ||= '';
 
-    $password ||= '';        # decode password from url
-    $password   =~ s/\+/ /g;
-    $password   =~ s/\%([A-Fa-f0-9]{2})/chr hex $1/ge;
+    for($username, $password)
+    {   s/\+/ /g;
+        s/\%([A-Fa-f0-9]{2})/chr hex $1/ge;
+    }
 
     $hostname ||= 'localhost';
 
@@ -564,5 +566,4 @@ sub decodeFolderURL($)
 #-------------------------------------------
 
 
-
 1;
