@@ -1,9 +1,14 @@
+# Copyrights 2001-2009 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Box::Parser;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.090';
+
 use base 'Mail::Reporter';
 use Carp;
 
@@ -19,6 +24,7 @@ sub new(@)
 sub init(@)
 {   my ($self, $args) = @_;
 
+#warn "PARSER type=".ref $self,$self->VERSION;
     $self->SUPER::init($args);
 
     $self->{MBP_mode} = $args->{mode} || 'r';
@@ -62,15 +68,12 @@ sub stop()
     $self->closeFile;
 }
 
-#------------------------------------------
-
 
 sub restart()
 {   my $self     = shift;
     my $filename = $self->filename;
 
-    $self->closeFile or return;
-
+    $self->closeFile;
     $self->openFile( {filename => $filename, mode => $self->{MBP_mode}} )
         or return;
 
@@ -79,8 +82,6 @@ sub restart()
     $self;
 }
 
-#------------------------------------------
-
 
 sub fileChanged()
 {   my $self = shift;
@@ -89,8 +90,6 @@ sub fileChanged()
     $size != $self->{MBP_size} || $mtime != $self->{MBP_mtime};
 }
     
-#------------------------------------------
-
 
 sub filename() {shift->{MBP_filename}}
 
@@ -99,48 +98,30 @@ sub filename() {shift->{MBP_filename}}
 
 sub filePosition(;$) {shift->NotImplemented}
 
-#------------------------------------------
-
 
 sub pushSeparator($) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub popSeparator($) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub readSeparator($) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub readHeader()    {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub bodyAsString() {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub bodyAsList() {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub bodyAsFile() {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub bodyDelayed() {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub lineSeparator() {shift->{MBP_linesep}}
 
@@ -149,21 +130,15 @@ sub lineSeparator() {shift->{MBP_linesep}}
 
 sub openFile(@) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub closeFile(@) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub takeFileInfo()
 {   my $self     = shift;
     @$self{ qw/MBP_size MBP_mtime/ } = (stat $self->filename)[7,9];
 }
 
-#------------------------------------------
-
 
 my $parser_type;
 
@@ -184,7 +159,7 @@ sub defaultParserType(;$)
 
     # Try to use C-based parser.
     eval 'require Mail::Box::Parser::C';
-#   warn "C-PARSER errors $@\n" if $@;
+#warn "C-PARSER errors $@\n" if $@;
 
     return $parser_type = 'Mail::Box::Parser::C'
         unless $@;
@@ -203,6 +178,4 @@ sub DESTROY
     $self->SUPER::DESTROY;
 }
 
-#------------------------------------------
-
 1;
