@@ -1,9 +1,14 @@
+# Copyrights 2001-2009 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.065';
+$VERSION = '2.090';
+
 
 use Mail::Message::Body::Multipart;
 use Mail::Message::Body::Nested;
@@ -16,7 +21,8 @@ sub forward(@)
 {   my $self    = shift;
     my %args    = @_;
 
-    return $self->forwardNo(@_) if exists $args{body};
+    return $self->forwardNo(@_)
+        if exists $args{body};
 
     my $include = $args{include} || 'INLINE';
     return $self->forwardInline(@_) if $include eq 'INLINE';
