@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Message::Field;
 use vars '$VERSION';
-$VERSION = '2.086';
+$VERSION = '2.090';
 
 use base 'Mail::Reporter';
 
@@ -305,7 +305,7 @@ sub toDate(@)
 {   my $class  = shift;
     my @time   = @_== 0 ? localtime() : @_==1 ? localtime(shift) : @_;
     my $format = "$weekday[$time[6]], %d $month[$time[4]] %Y %H:%M:%S %z";
-    my $time   = strftime($format, @time);
+    my $time   = strftime $format, @time;
 
     # for C libs which do not (GNU compliantly) support %z
     $time =~ s/ (\%z|[A-Za-z ]+)$/_tz_offset($1)/e;
