@@ -1,10 +1,15 @@
+# Copyrights 2001-2009 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 use warnings;
 
 package Mail::Message::Replace::MailInternet;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.090';
+
 use base 'Mail::Message';
 
 use Mail::Box::FastScalar;
@@ -340,10 +345,10 @@ sub as_mbox_string()
 
 BEGIN {
  no warnings;
- *Mail::Internet::new =
-    sub { my $class = shift;
-          Mail::Message::Replace::MailInternet->new(@_);
-        }
+ *Mail::Internet::new = sub (@)
+   { my $class = shift;
+     Mail::Message::Replace::MailInternet->new(@_);
+   };
 }
 
 
